@@ -1,6 +1,6 @@
 from asyncio import Queue
 
-from asyncpg.connection import Connection
+from asyncpg.connection import Connection, ConnectionMeta
 
 from .mockpreparedstmt import MockPreparedStatement
 
@@ -8,6 +8,15 @@ results = Queue()
 completed_queries = []
 
 
+def __subclasscheck__(cls, subclass):
+        if subclass == MockConnection:
+            return True
+        return old_subclass_check(cls, subclass)
+
+old_subclass_check = ConnectionMeta.__subclasscheck__
+ConnectionMeta.__subclasscheck__ = __subclasscheck__
+
+
 class MockConnection:
     __slots__ = Connection.__slots__
 
